@@ -7,18 +7,26 @@ import re
 import sys
 from itertools import zip_longest
 from pathlib import Path
+
 import yaml
-from mkdocs_obsidian.common import global_value as config
-
-BASEDIR = config.BASEDIR
+from rich import print
 
 
-def code_blocks(start_list: list, end_list: list):
-    """
-    Check all code blocks in the contents
-    :param start_list: List of all started codeblocs
-    :param end_list: list of all ended code blocks
-    :return: merged list
+def code_blocks(start_list, end_list):
+    """Check all code blocks in the contents
+
+    Parameters
+    ----------
+    start_list : list
+        List of all started codeblocs
+    end_list : list
+        list of all ended code blocks
+
+    Returns
+    -------
+    merged: list
+        Merged list for start and end
+
     """
     start_bug = []
     end_bug = []
@@ -42,11 +50,20 @@ def code_blocks(start_list: list, end_list: list):
     return merged
 
 
-def admonition_trad(file_data: list):
-    """
-    Change all admonition to material admonition
-    :param file_data: Contents of the file
-    :return: Admonition Converted contents
+def admonition_trad(BASEDIR, file_data: list):
+    """Change all admonition to material admonition
+
+    Parameters
+    ----------
+    BASEDIR: Path
+        Basedirectory from configuration
+    file_data : list
+        Contents of the file
+
+    Returns
+    -------
+    list:
+       All file contents with admonition converted
     """
     code_index = 0
     code_dict = {}
@@ -80,7 +97,6 @@ def admonition_trad(file_data: list):
         "bug",
         "example",
         "exemple",
-        "abstract",
         "quote",
         "cite",
     ]
@@ -96,11 +112,12 @@ def admonition_trad(file_data: list):
             try:
                 custom = yaml.safe_load(stream)
             except yaml.YAMLError:
-                sys.exit(
-                    f"Error in {admonition_custom} : Your YAML frontmatter doesn't seem"
-                    " valid! Use https://jsonformatter.org/yaml-validator to"
-                    " correct it!"
+                print(
+                    f"[red bold] Error in [u]{admonition_custom}[/] : Your YAML"
+                    " frontmatter doesn't seem valid! Use"
+                    " https://jsonformatter.org/yaml-validator to correct it!"
                 )
+                sys.exit(2)
     adm_list = adm_list + custom
     for i in range(0, len(file_data)):
         if re.search("[`?!]{3}( ?)\w+(.*)", file_data[i]):
@@ -179,3 +196,81 @@ def admonition_trad(file_data: list):
             file_data[ad_start] = file_data[ad_start].lstrip()
             file_data[ad_end] = file_data[ad_end].lstrip()
     return file_data
+
+def custom_callout(BASEDIR):
+    admonition_custom = False
+    if os.path.exists(Path(f"{BASEDIR}/assets/script/custom_admonition.yml")):
+        admonition_custom = Path(f"{BASEDIR}/assets/script/custom_admonition.yml")
+    elif os.path.exists(Path(f"{BASEDIR}/custom_admonition.yml")):
+        admonition_custom = Path(f"{BASEDIR}/custom_admonition.yml")
+
+    if admonition_custom:
+        with open(admonition_custom, "r", encoding="utf-8") as stream:
+            try:
+                custom = yaml.safe_load(stream)
+            except yaml.YAMLError:
+                print(
+                    f"[red bold] Error in [u]{admonition_custom}[/] : Your YAML"
+                    " frontmatter doesn't seem valid! Use"
+                    " https://jsonformatter.org/yaml-validator to correct it!"
+                    )
+                sys.exit(2)
+    callout_list = [
+        "note",
+        "abstract",
+        "summary",
+        "tldr",
+        "info",
+        "todo",
+        "tip",
+        "hint",
+        "important",
+        "success",
+        "check",
+        "done",
+        "question",
+        "help",
+        "faq",
+        "warning",
+        "caution",
+        "attention",
+        "failure",
+        "fail",
+        "missing",
+        "danger",
+        "error",
+        "bug",
+        "example",
+        "exemple",
+        "quote",
+        "cite",
+    ]
+    callout = callout_list + custom
+    return callout
+
+def parse_title(line, basedir):
+    callout = custom_callout(basedir)
+    title = re.search("> \[!(.*)\]", line)
+    rest_line = re.sub("> \[!(.*)\][\+\-]?", "", line)
+    if title.group(1).lower() not in callout:
+        title = "NOTE"
+    else:
+        title =  title.group(1)
+    if ']-' in line:
+        title = "??? " + title
+    elif "]+" in line:
+         title = "???+ " + title
+    else:
+        title = "!!! " + title
+    if len(rest_line) > 1:
+        title = title + " \"" + rest_line.strip() + "\""
+    return title + '\n'
+
+def callout_conversion(line, callout_state):
+    final_text = line
+    if callout_state:
+        if line.startswith('>'):
+            final_text = line.replace('>', '\t')
+        else:
+            callout_state=final_text
+    return final_text, callout_state
