@@ -14,37 +14,45 @@ import unidecode
 
 from mkdocs_obsidian.common import (
     file_checking as check,
-    global_value as config,
     metadata as mt,
     admonition as adm,
-)
-
-BASEDIR = Path(config.BASEDIR)
-VAULT = Path(config.VAULT)
-VAULT_FILE = config.VAULT_FILE
-SHARE = config.SHARE
+    )
 
 
-def get_image(image):
+def get_image(configuration, image):
+    """Check if the image exists in the VAULT
+
+    Parameters
+    ----------
+    configuration: dict
+    image : str
+
+    Returns
+    -------
+    str:
+        Path to image if True, False otherwise
+
     """
-    Check if the image exists in the VAULT
-    :param image: str
-    :return: bool or filepath to image
-    """
-    for filepath in VAULT_FILE:
-        if unidecode.unidecode(os.path.basename(filepath)) == unidecode.unidecode(
-            image
-        ):
+    VAULT_FILE = configuration["vault_file"]
+    shortname = unidecode.unidecode(os.path.splitext(image)[0])
+    assets = [x for x in VAULT_FILE if not x.endswith(".md")]
+    for filepath in assets:
+        file_name = unidecode.unidecode(os.path.splitext(os.path.basename(filepath))[0])
+        if file_name == shortname:
             return filepath
     return False
 
 
-def copy_image(final_text):
-    """
-    Copy the image if exist
-    :param final_text: str
-    :return: None
+def copy_image(configuration, final_text):
+    """Copy the image in assets if exist
+
+    Parameters
+    ----------
+    configuration: dict
+    final_text : str
+        Line readed
     """
+    IMG = configuration["img"]
     list_text = final_text.split("!")
     if len(list_text) > 0:
         for i in list_text:
@@ -52,19 +60,27 @@ def copy_image(final_text):
             if link:
                 final_text = re.sub("(!?|\(|(%20)|\[|\]|\))", "", i)
                 final_text = os.path.basename(final_text.split("|")[0])
-                image_path = get_image(final_text)
-                if image_path and os.path.isfile(image_path):
+                image_path = get_image(configuration, final_text)
+                if (
+                    image_path
+                    and os.path.isfile(image_path)
+                    and not image_path.endswith(".md")
+                ):
                     shutil.copyfile(
-                        image_path, Path(f"{config.IMG}/{os.path.basename(image_path)}")
+                        image_path, Path(f"{IMG}/{os.path.basename(image_path)}")
                     )
 
 
-def clipboard(filepath, folder):
-    """
-    Copy file URL to clipboard
-    :param filepath: str
-    :param folder: str
-    :return: None
+def clipboard(configuration, filepath, folder):
+    """Copy file URL to clipboard
+
+    Parameters
+    ----------
+    configuration: dict
+    filepath : str
+        Path to the file
+    folder: str
+        Path to folder
     """
     filename = os.path.basename(filepath)
     filename = filename.replace(".md", "")
@@ -72,22 +88,14 @@ def clipboard(filepath, folder):
     if filename == folder:
         filename = ""
     paste = url.quote(f"{folder_key}/{filename}")
-    clip = f"{config.WEB}{paste}"
-    if "iPhone" in platform.uname().machine or "iPad" in platform.uname().machine:
+    clip = f"{configuration['web']}{paste}"
+    if platform.architecture()[1] == "":
         try:
             import pasteboard  # work with pyto
 
             pasteboard.set_string(clip)
         except ImportError:
-            try:
-                import clipboard  # work with pytonista
-
-                clipboard.set(clip)
-            except ImportError:
-                print(
-                    "Please, report issue with your OS and configuration to check if it"
-                    " possible to use another clipboard manager"
-                )
+            pass
     else:
         try:
             # trying to use Pyperclip
@@ -101,24 +109,40 @@ def clipboard(filepath, folder):
             )
 
 
-def file_write(filepath, contents: list, folder, preserve=0, meta_update=1):
-    """
-    Write the new converted file and update metadata if meta_update is 0
-    :param filepath: file to convert
-    :param contents: File contents
-    :param folder: folderpath in publish
-    :param preserve: Change shared state in frontmatter if 1
-    :param meta_update: Update frontmatter if meta_update = 0
-    :return: True if file is created, False otherwise
+def file_write(configuration, filepath, contents, folder, preserve=0, meta_update=1):
+    """Write the new converted file and update metadata if meta_update is 0
+
+    Parameters
+    ----------
+    configuration: dict
+    filepath : str, Path
+        file to convert
+    contents: list
+        File contents
+    folder: str, Path
+        folderpath in publish
+    preserve: int, default: 0
+        Change shared state in frontmatter if 1
+    meta_update: int, default: 1
+        Update frontmatter if meta_update = 0
+
+    Returns
+    -------
+    bool:
+        True if file is created, False otherwise
+
     """
+    SHARE = configuration["share"]
     file_name = os.path.basename(filepath)
+    shortname = unidecode.unidecode(os.path.splitext(file_name)[0])
+    foldername = unidecode.unidecode(Path(folder).name)
     meta = frontmatter.load(filepath)
     if contents == "":
         return False
     if preserve == 0 and not meta.get(SHARE):
         check.delete_file(filepath, folder, meta_update)
         return False
-    if os.path.splitext(file_name)[0] == Path(folder).name:
+    if shortname == foldername:
         file_name = "index.md"
     with open(Path(f"{folder}/{file_name}"), "w", encoding="utf-8") as new_notes:
         for line in contents:
@@ -132,10 +156,17 @@ def file_write(filepath, contents: list, folder, preserve=0, meta_update=1):
     return True
 
 
-def read_custom():
-    """
-    read custom css
-    :return: A list of the id in the CSS file
+def read_custom(BASEDIR):
+    """read custom css, selection of id for custom attribute (special hashtags)
+
+    Parameters
+    ----------
+    BASEDIR: Path
+
+    Returns
+    -------
+    id_css:
+        List of the custom attribute CSS founded
     """
     id_css = []
     with open(
@@ -147,13 +178,21 @@ def read_custom():
     return id_css
 
 
-def convert_hashtags(final_text: str):
+def convert_hashtags(configuration, final_text):
+    """Convert configured hashtags with inline attribute CSS from custom.css
+
+    Parameters
+    ----------
+    configuration: dict
+    final_text: str
+        A line of the contents to convert if contains hashtags
+    Returns
+    -------
+    final_text: str
+        converted line
+
     """
-    Convert configured hashtags with ial CSS from custom.css
-    :param final_text: A line of the contents to convert if contains hashtags
-    :return: str
-    """
-    css = read_custom()
+    css = read_custom(configuration["basedir"])
     token = re.findall("#\w+", final_text)
     token = list(set(token))
     for i in range(0, len(token)):
@@ -168,7 +207,7 @@ def convert_hashtags(final_text: str):
                     + final_text.replace("#", "").strip()
                     + "**{: "
                     + token[i]
-                    + "}  \n"
+                    + "}\n"
                 )
             else:
                 ial = "**" + final_text.strip() + "**{: " + token[i] + "}  \n"
@@ -179,13 +218,29 @@ def convert_hashtags(final_text: str):
                 + token[i].replace("#", " ").strip()
                 + "**{: "
                 + token[i].strip()
-                + "}{: .hash}  \n"
+                + " .hash}  \n"
             )
+
             final_text = final_text.replace(token[i], ial, 1)
+
     return final_text
 
 
-def index_path(file_name):
+def index_path(file_name, VAULT_FILE):
+    """
+    Get the path of a founded index.md
+
+    Parameters
+    ----------
+    file_name: str
+        File found to be an index
+    VAULT_FILE: list[str]
+
+    Returns
+    -------
+    index: str
+        converted url path with category/index.md
+    """
     file = [x for x in VAULT_FILE if os.path.basename(x) == file_name + ".md"]
     index = "index"
     if file:
@@ -198,12 +253,30 @@ def index_path(file_name):
     return index
 
 
-def index_citation(final_text: str):
+def index_citation(final_text, configuration):
     """
-    :param final_text: Line to check, wikilinks or MD links
-    :return: Invert the alias with the name to get the index citation
+    Allow the citation of index.md by citation with configured INDEX_KEY.
+    Invert the alias and filename, replace filename by `category/index`
+
+    Examples
+    --------
+    - `[[filename|(i) Alias]]`  -> `[[index|Alias]]`
+    - `[[filename|(i)]]`  -> `[[index|filename]]`
+
+    Parameters
+    ----------
+    configuration: dict
+    final_text : str
+        Line to check, wikilinks or MD links
+
+    Returns
+    -------
+    final_text: str
+        Return the line with alias and file name inverted
+
     """
-    INDEX_KEY = config.INDEX_KEY
+    INDEX_KEY = configuration["index_key"]
+    VAULT_FILE = configuration["vault_file"]
     if ") [" in final_text:
         cited = (
             re.search(
@@ -248,7 +321,7 @@ def index_citation(final_text: str):
                         .replace("[", "")
                         .replace(INDEX_KEY, "")
                     )
-                index = index_path(file_name)
+                index = index_path(file_name, VAULT_FILE)
                 cite = f"[[{index}|" + file_name.strip()
                 final_text = final_text.replace(i, cite)
             elif re.search(r"(.*)" + re.escape(INDEX_KEY) + r"(.*)\]", i):
@@ -261,7 +334,7 @@ def index_citation(final_text: str):
                 )
                 if len(file_name) == 0:
                     file_name = re.search("\]\((.*)", i).group(1).replace(")", "")
-                index = index_path(file_name)
+                index = index_path(file_name, VAULT_FILE)
                 cite = "[" + file_name + f"]({index})"
                 final_text = (
                     final_text.replace(i, cite)
@@ -272,20 +345,33 @@ def index_citation(final_text: str):
     return final_text
 
 
-def file_convert(filepath, force=0):
-    """
-    Read the filepath and convert each line based on regex condition.
-    :param filepath: path to file
-    :param force: deletion option
-    :return: converted contents
+def file_convert(configuration, filepath, force=0):
+    """Read the filepath and convert each line based on regex condition.
+
+    Parameters
+    ----------
+    configuration: dict
+    filepath : str
+        path to file
+    force : int, default: 0
+        deletion option
+
+    Returns
+    -------
+    final: list[str]
+        converted contents, ready for writing.
+
     """
     final = []
-    INDEX_KEY = config.INDEX_KEY
+
+    INDEX_KEY = configuration["index_key"]
+    SHARE = configuration["share"]
     meta = frontmatter.load(filepath)
     lines = meta.content.splitlines(True)
     if force != 1 and not meta.get(SHARE):
         return final
-    lines = adm.admonition_trad(lines)
+    lines = adm.admonition_trad(configuration["basedir"], lines)
+    callout_state= False
     for line in lines:
         final_text = line
         if not final_text.strip().endswith("%%") and not final_text.strip().startswith(
@@ -293,7 +379,7 @@ def file_convert(filepath, force=0):
         ):
             # Skip obsidian comments
             # Check and copy image
-            copy_image(final_text)
+            copy_image(configuration, final_text)
             if not "`" in final_text:
                 final_text = re.sub(
                     "\%{2}(.*)\%{2}", "", final_text
@@ -310,16 +396,20 @@ def file_convert(filepath, force=0):
                     .decode("utf-16")
                 )
                 final_text = re.sub(r"\\U\w+", convert_emojiz, final_text)
+            if final_text.startswith('> [!'):
+                callout_state = True
+                final_text = adm.parse_title(line, configuration['basedir'])
+            final_text, callout_state = adm.callout_conversion(final_text, callout_state)
             if re.search(
                 rf"\[\[?(.*)" + re.escape(INDEX_KEY) + r"(.*)\]\]?", final_text
             ):
                 # fix pagination.indexes page citation, exclude image/embed file
-                final_text = index_citation(final_text)
+                final_text = index_citation(final_text, configuration)
             if re.search("#\w+", final_text) and not re.search(
                 "(`|\[{2}|\()(.*)#(.*)(`|\]{2}|\))", final_text
             ):  # search hashtags not in link
                 # Convert hashtags
-                final_text = convert_hashtags(final_text)
+                final_text = convert_hashtags(configuration, final_text)
             elif re.fullmatch(
                 "\\\\", final_text.strip()
             ):  # New line when using "\" in obsidian filepath
