@@ -9,68 +9,84 @@ from pathlib import Path
 
 import frontmatter
 import yaml
+from rich import print
+from rich.console import Console
+from rich.markdown import Markdown
 from rich.progress import track
 from rich.rule import Rule
-from rich.markdown import Markdown
-from rich.console import Console
-from rich import print
+
 from mkdocs_obsidian.common import (
     config,
-    global_value as gl,
     file_checking as check,
     conversion as convert,
-)
-
-BASEDIR = gl.BASEDIR
-VAULT = gl.VAULT
-VAULT_FILE = gl.VAULT_FILE
-SHARE = gl.SHARE
-INDEX_KEY = gl.INDEX_KEY
+    )
 
 
-def exclude_folder(filepath: str):
+def dest(filepath, folder):
     """
-    Check if the file is in an excluded folder
-    :param filepath: file to check
-    :return: boolean
-    """
-    config_folder = Path(f"{BASEDIR}/exclude_folder.yml")
-    if os.path.exists(config_folder):
-        with open(config_folder, "r", encoding="utf-8") as file_config:
-            try:
-                folder = yaml.safe_load(file_config)
-            except yaml.YAMLError as exc:
-                print(exc)
-                sys.exit(1)
-        return any(str(Path(file)) in filepath for file in folder)
-    return False
+    Returns the final destination path of the file.
 
+    Parameters
+    ----------
+    filepath : str
+        file to convert
+    folder : str | Path
+        final folder
 
-def dest(filepath: str, folder: str):
-    """
-    Return the path of the final file
-    :param filepath: file to convert
-    :param folder: final folder
-    :return: str
+    Returns
+    -------
+    destination: str
     """
     file_name = os.path.basename(filepath)
     destination = Path(f"{folder}/{file_name}")
     return str(destination)
 
 
-def search_share(preserve=0, stop_share=1, meta=0, vault_share=0, obsidian=False):
-    """
-    Search file to publish
-    :param obsidian: Use normal printing for obsidian_shell
-    :param preserve: if 1 force update
-    :param stop_share: remove stoped shared file if 1
-    :param meta: Update the metadata if 1
-    :param vault_share: If all the vault need to be shared
-    :return: Contents of the notes
+def search_share(
+    configuration, preserve=0, stop_share=1, meta=0, vault_share=0, obsidian=False
+):
+    """Search file to publish, convert and write them.
+
+    Parameters
+    ----------
+    configuration: dict
+        configuration value with :
+        - basedir
+        - vault
+        - web
+        - share
+        - index_key
+        - default_note
+        - post
+        - img
+        - vault_file
+    obsidian: bool, default: False
+        Use normal printing for obsidian_shell (Default value = False)
+    preserve: int, default: 1
+        if 1 force update
+    stop_share: int, default: 1
+        remove stoped shared file if 1
+    meta: int, default: 0
+        Update the metadata if 1
+    vault_share: int, default: 0
+        If all the vault need to be shared
+
+    Returns
+    -------
+    tuple:
+        filepush: list[str]
+            Founded files
+        clipkey: str, default = DEFAULT_NOTES
+            Category key
+
     """
+
+    DEFAULT_NOTES = configuration["default_note"]
+    VAULT_FILE = configuration["vault_file"]
+    SHARE = configuration["share"]
     filespush = []
     check_file = False
-    clipkey = "notes"
+    clipkey = DEFAULT_NOTES
     description = "[cyan u]Scanning\n"
     for filepath in track(
         VAULT_FILE, description=description, total=len(VAULT_FILE), disable=obsidian
@@ -78,15 +94,15 @@ def search_share(preserve=0, stop_share=1, meta=0, vault_share=0, obsidian=False
         if (
             filepath.endswith(".md")
             and "excalidraw" not in filepath
-            and not exclude_folder(filepath)
+            and not check.exclude(filepath, "folder", configuration["basedir"])
         ):
             try:
                 yaml_front = frontmatter.load(filepath)
-                clipkey = yaml_front.get("category", "notes")
+                clipkey = yaml_front.get("category", DEFAULT_NOTES)
                 if not clipkey:
                     clipkey = "hidden"
                 if yaml_front.get(SHARE) or vault_share == 1:
-                    folder = check.create_folder(clipkey, 0)
+                    folder = check.create_folder(clipkey, configuration, 0)
                     if preserve == 0:  # preserve
                         if yaml_front.get("update") is False:
                             update = 1
@@ -98,17 +114,21 @@ def search_share(preserve=0, stop_share=1, meta=0, vault_share=0, obsidian=False
                         ) or not check.modification_time(filepath, folder, update):
                             check_file = False
                         else:
-                            contents = convert.file_convert(filepath, vault_share)
+                            contents = convert.file_convert(
+                                configuration, filepath, vault_share
+                            )
                             if check.diff_file(filepath, folder, contents, update):
                                 check_file = convert.file_write(
-                                    filepath, contents, folder, meta
+                                    configuration, filepath, contents, folder, meta
                                 )
                             else:
                                 check_file = False
                     elif preserve == 1:  # force deletions
-                        contents = convert.file_convert(filepath, vault_share)
+                        contents = convert.file_convert(
+                            configuration, filepath, vault_share
+                        )
                         check_file = convert.file_write(
-                            filepath, contents, folder, meta
+                            configuration, filepath, contents, folder, meta
                         )
                     msg_folder = os.path.basename(folder)
                     destination = dest(filepath, folder)
@@ -119,7 +139,7 @@ def search_share(preserve=0, stop_share=1, meta=0, vault_share=0, obsidian=False
                             f" [{msg_folder}]"
                         )
                 elif stop_share == 1:
-                    folder = check.create_folder(clipkey, 1)
+                    folder = check.create_folder(clipkey, configuration, 1)
                     file_name = os.path.basename(filepath).replace(".md", "")
                     if file_name == os.path.basename(folder):
                         filepath = filepath.replace(file_name, "index")
@@ -141,15 +161,35 @@ def search_share(preserve=0, stop_share=1, meta=0, vault_share=0, obsidian=False
     return filespush, clipkey
 
 
-def obsidian_simple(delopt=False, git=True, stop_share=0, meta=0, vault_share=0):
+def obsidian_simple(
+    configuration, delopt=False, git=True, stop_share=0, meta=0, vault_share=0
+):
     """
-    Main function to convert multiple file in obsidian shell
-    :param delopt: Force deletion if True
-    :param git: Git push if True
-    :param stop_share: Delete stoped shared file if 0
-    :param meta: Update frontmatter if 1
-    :param vault_share: Share all file in vault if 1
-    :return: None
+    Convert file without markup for obsidian shell command.
+
+    Parameters
+    ----------
+    configuration: dict
+        configuration value with :
+        - basedir
+        - vault
+        - web
+        - share
+        - index_key
+        - default_note
+        - post
+        - img
+        - vault_file
+    delopt : bool, default: False
+        Force deletion if True
+    git: bool, default: True
+        Git push if True
+    stop_share: int, default: 0
+        Delete stoped shared file if 0
+    meta: int, default: 0
+        Update frontmatter if 1
+    vault_share: int, default: 0
+        Share all file in vault if 1
     """
     if not git:
         git_info = "No push"
@@ -158,19 +198,19 @@ def obsidian_simple(delopt=False, git=True, stop_share=0, meta=0, vault_share=0)
     time_now = datetime.now().strftime("%H:%M:%S")
     msg_info = ""
     if vault_share == 1:
-        msg_info = "\n- Share entire vault [**ignore share**]"
+        msg_info = "\n- Share entire vault [ignore share]"
     if delopt:  # preservesdds
         print(
             f"[{time_now}] STARTING CONVERT ALL\n\n- {git_info}\n- Force"
             f" deletion{msg_info}"
         )
         new_files, clipkey = search_share(
-            1, stop_share, meta, vault_share, obsidian=True
+            configuration, 1, stop_share, meta, vault_share, obsidian=True
         )
     else:
         print(f"[{time_now}] STARTING CONVERT ALL\n- {git_info}\n{msg_info}")
         new_files, clipkey = search_share(
-            0, stop_share, meta, vault_share, obsidian=True
+            configuration, 0, stop_share, meta, vault_share, obsidian=True
         )
     if len(new_files) > 0:
         add_msg = ""
@@ -193,10 +233,11 @@ def obsidian_simple(delopt=False, git=True, stop_share=0, meta=0, vault_share=0)
             if len(new_files) == 1:
                 commit = "".join(new_files)
                 markdown_msg = commit[commit.find(":") + 2 : commit.rfind("in") - 1]
-                convert.clipboard(markdown_msg, clipkey)
+                convert.clipboard(configuration, markdown_msg, clipkey)
             commit = f"Updated :\n\n {commit}\n"
             config.git_push(
                 commit,
+                configuration,
                 True,
                 add_info=add_info,
                 rmv_info=remove_info,
@@ -213,15 +254,35 @@ def obsidian_simple(delopt=False, git=True, stop_share=0, meta=0, vault_share=0)
     sys.exit()
 
 
-def convert_all(delopt=False, git=True, stop_share=0, meta=0, vault_share=0):
-    """
-    Main function to convert multiple file
-    :param delopt: Force deletion if True
-    :param git: Git push if True
-    :param stop_share: Delete stoped shared file if 0
-    :param meta: Update frontmatter if 1
-    :param vault_share: Share all file in vault if 1
-    :return: None
+def convert_all(
+    configuration, delopt=False, git=True, stop_share=0, meta=0, vault_share=0
+):
+    """Convert all shared file with relying on rich markup library.
+
+    Parameters
+    ----------
+    configuration: dict
+        configuration value with :
+        - basedir
+        - vault
+        - web
+        - share
+        - index_key
+        - default_note
+        - post
+        - img
+        - vault_file
+    delopt: bool, default: False
+        Force deletion if True
+    git: bool, default: True
+        Git push if True
+    stop_share: int, default: 0
+        Delete stoped shared file if 0
+    meta: int, default: 0
+        Update source file frontmatter if 1
+    vault_share: int, default: 0
+        Share all file in vault if 1
+
     """
     console = Console()
     if not git:
@@ -246,7 +307,9 @@ def convert_all(delopt=False, git=True, stop_share=0, meta=0, vault_share=0):
             new_line_start=True,
             justify="full",
         )
-        new_files, clipkey = search_share(1, stop_share, meta, vault_share)
+        new_files, clipkey = search_share(
+            configuration, 1, stop_share, meta, vault_share
+        )
     else:
         console.print(
             Rule(
@@ -260,7 +323,9 @@ def convert_all(delopt=False, git=True, stop_share=0, meta=0, vault_share=0):
             " ",
             new_line_start=True,
         )
-        new_files, clipkey = search_share(0, stop_share, meta, vault_share)
+        new_files, clipkey = search_share(
+            configuration, 0, stop_share, meta, vault_share
+        )
     if len(new_files) > 0:
         add_msg = ""
         remove_msg = ""
@@ -282,10 +347,11 @@ def convert_all(delopt=False, git=True, stop_share=0, meta=0, vault_share=0):
             if len(new_files) == 1:
                 commit = "".join(new_files)
                 markdown_msg = commit[commit.find(":") + 2 : commit.rfind("in") - 1]
-                convert.clipboard(markdown_msg, clipkey)
+                convert.clipboard(configuration, markdown_msg, clipkey)
             commit = f"**Updated** : \n {commit}\n"
             config.git_push(
                 commit,
+                configuration,
                 add_info=add_info,
                 rmv_info=remove_info,
                 add_msg=add_msg,
